==> knative-model-6.9.0-sources.jar: io/fabric8/knative/flows/v1/ParallelBranchStatusFluent.java <==
package io.fabric8.knative.flows.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ParallelBranchStatusFluent<A extends ParallelBranchStatusFluent<A>> extends BaseFluent<A>{
  public ParallelBranchStatusFluent() {
  }
  
  public ParallelBranchStatusFluent(ParallelBranchStatus instance) {
    this.copyInstance(instance);
  }
  private ParallelChannelStatusBuilder filterChannelStatus;
  private ParallelSubscriptionStatusBuilder filterSubscriptionStatus;
  private ParallelSubscriptionStatusBuilder subscriberSubscriptionStatus;
  
  protected void copyInstance(ParallelBranchStatus instance) {
    instance = (instance != null ? instance : new ParallelBranchStatus());
  
    if (instance != null) {
        this.withFilterChannelStatus(instance.getFilterChannelStatus());
        this.withFilterSubscriptionStatus(instance.getFilterSubscriptionStatus());
        this.withSubscriberSubscriptionStatus(instance.getSubscriberSubscriptionStatus());
        this.withFilterChannelStatus(instance.getFilterChannelStatus());
        this.withFilterSubscriptionStatus(instance.getFilterSubscriptionStatus());
        this.withSubscriberSubscriptionStatus(instance.getSubscriberSubscriptionStatus());
      }
  }
  
  public ParallelChannelStatus buildFilterChannelStatus() {
    return this.filterChannelStatus!=null ?this.filterChannelStatus.build():null;
  }
  
  public A withFilterChannelStatus(ParallelChannelStatus filterChannelStatus) {
    _visitables.get("filterChannelStatus").remove(this.filterChannelStatus);
    if (filterChannelStatus!=null){ this.filterChannelStatus= new ParallelChannelStatusBuilder(filterChannelStatus); _visitables.get("filterChannelStatus").add(this.filterChannelStatus);} else { this.filterChannelStatus = null; _visitables.get("filterChannelStatus").remove(this.filterChannelStatus); } return (A) this;
  }
  
  public boolean hasFilterChannelStatus() {
    return this.filterChannelStatus != null;
  }
  
  public FilterChannelStatusNested<A> withNewFilterChannelStatus() {
    return new FilterChannelStatusNested(null);
  }
  
  public FilterChannelStatusNested<A> withNewFilterChannelStatusLike(ParallelChannelStatus item) {
    return new FilterChannelStatusNested(item);
  }
  
  public FilterChannelStatusNested<A> editFilterChannelStatus() {
    return withNewFilterChannelStatusLike(java.util.Optional.ofNullable(buildFilterChannelStatus()).orElse(null));
  }
  
  public FilterChannelStatusNested<A> editOrNewFilterChannelStatus() {
    return withNewFilterChannelStatusLike(java.util.Optional.ofNullable(buildFilterChannelStatus()).orElse(new ParallelChannelStatusBuilder().build()));
  }
  
  public FilterChannelStatusNested<A> editOrNewFilterChannelStatusLike(ParallelChannelStatus item) {
    return withNewFilterChannelStatusLike(java.util.Optional.ofNullable(buildFilterChannelStatus()).orElse(item));
  }
  
  public ParallelSubscriptionStatus buildFilterSubscriptionStatus() {
    return this.filterSubscriptionStatus!=null ?this.filterSubscriptionStatus.build():null;
  }
  
  public A withFilterSubscriptionStatus(ParallelSubscriptionStatus filterSubscriptionStatus) {
    _visitables.get("filterSubscriptionStatus").remove(this.filterSubscriptionStatus);
    if (filterSubscriptionStatus!=null){ this.filterSubscriptionStatus= new ParallelSubscriptionStatusBuilder(filterSubscriptionStatus); _visitables.get("filterSubscriptionStatus").add(this.filterSubscriptionStatus);} else { this.filterSubscriptionStatus = null; _visitables.get("filterSubscriptionStatus").remove(this.filterSubscriptionStatus); } return (A) this;
  }
  
  public boolean hasFilterSubscriptionStatus() {
    return this.filterSubscriptionStatus != null;
  }
  
  public FilterSubscriptionStatusNested<A> withNewFilterSubscriptionStatus() {
    return new FilterSubscriptionStatusNested(null);
  }
  
  public FilterSubscriptionStatusNested<A> withNewFilterSubscriptionStatusLike(ParallelSubscriptionStatus item) {
    return new FilterSubscriptionStatusNested(item);
  }
  
  public FilterSubscriptionStatusNested<A> editFilterSubscriptionStatus() {
    return withNewFilterSubscriptionStatusLike(java.util.Optional.ofNullable(buildFilterSubscriptionStatus()).orElse(null));
  }
  
  public FilterSubscriptionStatusNested<A> editOrNewFilterSubscriptionStatus() {
    return withNewFilterSubscriptionStatusLike(java.util.Optional.ofNullable(buildFilterSubscriptionStatus()).orElse(new ParallelSubscriptionStatusBuilder().build()));
  }
  
  public FilterSubscriptionStatusNested<A> editOrNewFilterSubscriptionStatusLike(ParallelSubscriptionStatus item) {
    return withNewFilterSubscriptionStatusLike(java.util.Optional.ofNullable(buildFilterSubscriptionStatus()).orElse(item));
  }
  
  public ParallelSubscriptionStatus buildSubscriberSubscriptionStatus() {
    return this.subscriberSubscriptionStatus!=null ?this.subscriberSubscriptionStatus.build():null;
  }
  
  public A withSubscriberSubscriptionStatus(ParallelSubscriptionStatus subscriberSubscriptionStatus) {
    _visitables.get("subscriberSubscriptionStatus").remove(this.subscriberSubscriptionStatus);
    if (subscriberSubscriptionStatus!=null){ this.subscriberSubscriptionStatus= new ParallelSubscriptionStatusBuilder(subscriberSubscriptionStatus); _visitables.get("subscriberSubscriptionStatus").add(this.subscriberSubscriptionStatus);} else { this.subscriberSubscriptionStatus = null; _visitables.get("subscriberSubscriptionStatus").remove(this.subscriberSubscriptionStatus); } return (A) this;
  }
  
  public boolean hasSubscriberSubscriptionStatus() {
    return this.subscriberSubscriptionStatus != null;
  }
  
  public SubscriberSubscriptionStatusNested<A> withNewSubscriberSubscriptionStatus() {
    return new SubscriberSubscriptionStatusNested(null);
  }
  
  public SubscriberSubscriptionStatusNested<A> withNewSubscriberSubscriptionStatusLike(ParallelSubscriptionStatus item) {
    return new SubscriberSubscriptionStatusNested(item);
  }
  
  public SubscriberSubscriptionStatusNested<A> editSubscriberSubscriptionStatus() {
    return withNewSubscriberSubscriptionStatusLike(java.util.Optional.ofNullable(buildSubscriberSubscriptionStatus()).orElse(null));
  }
  
  public SubscriberSubscriptionStatusNested<A> editOrNewSubscriberSubscriptionStatus() {
    return withNewSubscriberSubscriptionStatusLike(java.util.Optional.ofNullable(buildSubscriberSubscriptionStatus()).orElse(new ParallelSubscriptionStatusBuilder().build()));
  }
  
  public SubscriberSubscriptionStatusNested<A> editOrNewSubscriberSubscriptionStatusLike(ParallelSubscriptionStatus item) {
    return withNewSubscriberSubscriptionStatusLike(java.util.Optional.ofNullable(buildSubscriberSubscriptionStatus()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ParallelBranchStatusFluent that = (ParallelBranchStatusFluent) o;
    if (!java.util.Objects.equals(filterChannelStatus, that.filterChannelStatus)) return false;
  
    if (!java.util.Objects.equals(filterSubscriptionStatus, that.filterSubscriptionStatus)) return false;
  
    if (!java.util.Objects.equals(subscriberSubscriptionStatus, that.subscriberSubscriptionStatus)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(filterChannelStatus,  filterSubscriptionStatus,  subscriberSubscriptionStatus,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (filterChannelStatus != null) { sb.append("filterChannelStatus:"); sb.append(filterChannelStatus + ","); }
    if (filterSubscriptionStatus != null) { sb.append("filterSubscriptionStatus:"); sb.append(filterSubscriptionStatus + ","); }
    if (subscriberSubscriptionStatus != null) { sb.append("subscriberSubscriptionStatus:"); sb.append(subscriberSubscriptionStatus); }
    sb.append("}");
    return sb.toString();
  }
  public class FilterChannelStatusNested<N> extends ParallelChannelStatusFluent<FilterChannelStatusNested<N>> implements Nested<N>{
    FilterChannelStatusNested(ParallelChannelStatus item) {
      this.builder = new ParallelChannelStatusBuilder(this, item);
    }
    ParallelChannelStatusBuilder builder;
    
    public N and() {
      return (N) ParallelBranchStatusFluent.this.withFilterChannelStatus(builder.build());
    }
    
    public N endFilterChannelStatus() {
      return and();
    }
    
  
  }
  public class FilterSubscriptionStatusNested<N> extends ParallelSubscriptionStatusFluent<FilterSubscriptionStatusNested<N>> implements Nested<N>{
    FilterSubscriptionStatusNested(ParallelSubscriptionStatus item) {
      this.builder = new ParallelSubscriptionStatusBuilder(this, item);
    }
    ParallelSubscriptionStatusBuilder builder;
    
    public N and() {
      return (N) ParallelBranchStatusFluent.this.withFilterSubscriptionStatus(builder.build());
    }
    
    public N endFilterSubscriptionStatus() {
      return and();
    }
    
  
  }
  public class SubscriberSubscriptionStatusNested<N> extends ParallelSubscriptionStatusFluent<SubscriberSubscriptionStatusNested<N>> implements Nested<N>{
    SubscriberSubscriptionStatusNested(ParallelSubscriptionStatus item) {
      this.builder = new ParallelSubscriptionStatusBuilder(this, item);
    }
    ParallelSubscriptionStatusBuilder builder;
    
    public N and() {
      return (N) ParallelBranchStatusFluent.this.withSubscriberSubscriptionStatus(builder.build());
    }
    
    public N endSubscriberSubscriptionStatus() {
      return and();
    }
    
  
  }

}

==> knative-model-6.13.3-sources.jar: io/fabric8/knative/flows/v1/ParallelBranchStatusFluent.java <==
package io.fabric8.knative.flows.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ParallelBranchStatusFluent<A extends ParallelBranchStatusFluent<A>> extends BaseFluent<A>{
  public ParallelBranchStatusFluent() {
  }
  
  public ParallelBranchStatusFluent(ParallelBranchStatus instance) {
    this.copyInstance(instance);
  }
  private ParallelChannelStatusBuilder filterChannelStatus;
  private ParallelSubscriptionStatusBuilder filterSubscriptionStatus;
  private ParallelSubscriptionStatusBuilder subscriberSubscriptionStatus;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ParallelBranchStatus instance) {
    instance = (instance != null ? instance : new ParallelBranchStatus());
    if (instance != null) {
          this.withFilterChannelStatus(instance.getFilterChannelStatus());
          this.withFilterSubscriptionStatus(instance.getFilterSubscriptionStatus());
          this.withSubscriberSubscriptionStatus(instance.getSubscriberSubscriptionStatus());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public ParallelChannelStatus buildFilterChannelStatus() {
    return this.filterChannelStatus != null ? this.filterChannelStatus.build() : null;
  }
  
  public A withFilterChannelStatus(ParallelChannelStatus filterChannelStatus) {
    this._visitables.remove("filterChannelStatus");
    if (filterChannelStatus != null) {
        this.filterChannelStatus = new ParallelChannelStatusBuilder(filterChannelStatus);
        this._visitables.get("filterChannelStatus").add(this.filterChannelStatus);
    } else {
        this.filterChannelStatus = null;
        this._visitables.get("filterChannelStatus").remove(this.filterChannelStatus);
    }
    return (A) this;
  }
  
  public boolean hasFilterChannelStatus() {
    return this.filterChannelStatus != null;
  }
  
  public FilterChannelStatusNested<A> withNewFilterChannelStatus() {
    return new FilterChannelStatusNested(null);
  }
  
  public FilterChannelStatusNested<A> withNewFilterChannelStatusLike(ParallelChannelStatus item) {
    return new FilterChannelStatusNested(item);
  }
  
  public FilterChannelStatusNested<A> editFilterChannelStatus() {
    return withNewFilterChannelStatusLike(java.util.Optional.ofNullable(buildFilterChannelStatus()).orElse(null));
  }
  
  public FilterChannelStatusNested<A> editOrNewFilterChannelStatus() {
    return withNewFilterChannelStatusLike(java.util.Optional.ofNullable(buildFilterChannelStatus()).orElse(new ParallelChannelStatusBuilder().build()));
  }
  
  public FilterChannelStatusNested<A> editOrNewFilterChannelStatusLike(ParallelChannelStatus item) {
    return withNewFilterChannelStatusLike(java.util.Optional.ofNullable(buildFilterChannelStatus()).orElse(item));
  }
  
  public ParallelSubscriptionStatus buildFilterSubscriptionStatus() {
    return this.filterSubscriptionStatus != null ? this.filterSubscriptionStatus.build() : null;
  }
  
  public A withFilterSubscriptionStatus(ParallelSubscriptionStatus filterSubscriptionStatus) {
    this._visitables.remove("filterSubscriptionStatus");
    if (filterSubscriptionStatus != null) {
        this.filterSubscriptionStatus = new ParallelSubscriptionStatusBuilder(filterSubscriptionStatus);
        this._visitables.get("filterSubscriptionStatus").add(this.filterSubscriptionStatus);
    } else {
        this.filterSubscriptionStatus = null;
        this._visitables.get("filterSubscriptionStatus").remove(this.filterSubscriptionStatus);
    }
    return (A) this;
  }
  
  public boolean hasFilterSubscriptionStatus() {
    return this.filterSubscriptionStatus != null;
  }
  
  public FilterSubscriptionStatusNested<A> withNewFilterSubscriptionStatus() {
    return new FilterSubscriptionStatusNested(null);
  }
  
  public FilterSubscriptionStatusNested<A> withNewFilterSubscriptionStatusLike(ParallelSubscriptionStatus item) {
    return new FilterSubscriptionStatusNested(item);
  }
  
  public FilterSubscriptionStatusNested<A> editFilterSubscriptionStatus() {
    return withNewFilterSubscriptionStatusLike(java.util.Optional.ofNullable(buildFilterSubscriptionStatus()).orElse(null));
  }
  
  public FilterSubscriptionStatusNested<A> editOrNewFilterSubscriptionStatus() {
    return withNewFilterSubscriptionStatusLike(java.util.Optional.ofNullable(buildFilterSubscriptionStatus()).orElse(new ParallelSubscriptionStatusBuilder().build()));
  }
  
  public FilterSubscriptionStatusNested<A> editOrNewFilterSubscriptionStatusLike(ParallelSubscriptionStatus item) {
    return withNewFilterSubscriptionStatusLike(java.util.Optional.ofNullable(buildFilterSubscriptionStatus()).orElse(item));
  }
  
  public ParallelSubscriptionStatus buildSubscriberSubscriptionStatus() {
    return this.subscriberSubscriptionStatus != null ? this.subscriberSubscriptionStatus.build() : null;
  }
  
  public A withSubscriberSubscriptionStatus(ParallelSubscriptionStatus subscriberSubscriptionStatus) {
    this._visitables.remove("subscriberSubscriptionStatus");
    if (subscriberSubscriptionStatus != null) {
        this.subscriberSubscriptionStatus = new ParallelSubscriptionStatusBuilder(subscriberSubscriptionStatus);
        this._visitables.get("subscriberSubscriptionStatus").add(this.subscriberSubscriptionStatus);
    } else {
        this.subscriberSubscriptionStatus = null;
        this._visitables.get("subscriberSubscriptionStatus").remove(this.subscriberSubscriptionStatus);
    }
    return (A) this;
  }
  
  public boolean hasSubscriberSubscriptionStatus() {
    return this.subscriberSubscriptionStatus != null;
  }
  
  public SubscriberSubscriptionStatusNested<A> withNewSubscriberSubscriptionStatus() {
    return new SubscriberSubscriptionStatusNested(null);
  }
  
  public SubscriberSubscriptionStatusNested<A> withNewSubscriberSubscriptionStatusLike(ParallelSubscriptionStatus item) {
    return new SubscriberSubscriptionStatusNested(item);
  }
  
  public SubscriberSubscriptionStatusNested<A> editSubscriberSubscriptionStatus() {
    return withNewSubscriberSubscriptionStatusLike(java.util.Optional.ofNullable(buildSubscriberSubscriptionStatus()).orElse(null));
  }
  
  public SubscriberSubscriptionStatusNested<A> editOrNewSubscriberSubscriptionStatus() {
    return withNewSubscriberSubscriptionStatusLike(java.util.Optional.ofNullable(buildSubscriberSubscriptionStatus()).orElse(new ParallelSubscriptionStatusBuilder().build()));
  }
  
  public SubscriberSubscriptionStatusNested<A> editOrNewSubscriberSubscriptionStatusLike(ParallelSubscriptionStatus item) {
    return withNewSubscriberSubscriptionStatusLike(java.util.Optional.ofNullable(buildSubscriberSubscriptionStatus()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ParallelBranchStatusFluent that = (ParallelBranchStatusFluent) o;
    if (!java.util.Objects.equals(filterChannelStatus, that.filterChannelStatus)) return false;
    if (!java.util.Objects.equals(filterSubscriptionStatus, that.filterSubscriptionStatus)) return false;
    if (!java.util.Objects.equals(subscriberSubscriptionStatus, that.subscriberSubscriptionStatus)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(filterChannelStatus,  filterSubscriptionStatus,  subscriberSubscriptionStatus,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (filterChannelStatus != null) { sb.append("filterChannelStatus:"); sb.append(filterChannelStatus + ","); }
    if (filterSubscriptionStatus != null) { sb.append("filterSubscriptionStatus:"); sb.append(filterSubscriptionStatus + ","); }
    if (subscriberSubscriptionStatus != null) { sb.append("subscriberSubscriptionStatus:"); sb.append(subscriberSubscriptionStatus + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class FilterChannelStatusNested<N> extends ParallelChannelStatusFluent<FilterChannelStatusNested<N>> implements Nested<N>{
    FilterChannelStatusNested(ParallelChannelStatus item) {
      this.builder = new ParallelChannelStatusBuilder(this, item);
    }
    ParallelChannelStatusBuilder builder;
    
    public N and() {
      return (N) ParallelBranchStatusFluent.this.withFilterChannelStatus(builder.build());
    }
    
    public N endFilterChannelStatus() {
      return and();
    }
    
  
  }
  public class FilterSubscriptionStatusNested<N> extends ParallelSubscriptionStatusFluent<FilterSubscriptionStatusNested<N>> implements Nested<N>{
    FilterSubscriptionStatusNested(ParallelSubscriptionStatus item) {
      this.builder = new ParallelSubscriptionStatusBuilder(this, item);
    }
    ParallelSubscriptionStatusBuilder builder;
    
    public N and() {
      return (N) ParallelBranchStatusFluent.this.withFilterSubscriptionStatus(builder.build());
    }
    
    public N endFilterSubscriptionStatus() {
      return and();
    }
    
  
  }
  public class SubscriberSubscriptionStatusNested<N> extends ParallelSubscriptionStatusFluent<SubscriberSubscriptionStatusNested<N>> implements Nested<N>{
    SubscriberSubscriptionStatusNested(ParallelSubscriptionStatus item) {
      this.builder = new ParallelSubscriptionStatusBuilder(this, item);
    }
    ParallelSubscriptionStatusBuilder builder;
    
    public N and() {
      return (N) ParallelBranchStatusFluent.this.withSubscriberSubscriptionStatus(builder.build());
    }
    
    public N endSubscriberSubscriptionStatus() {
      return and();
    }
    
  
  }

}
